@@ -4,15 +4,40 @@
 <context>
     <name>AccessPointGUI</name>
     <message>
-        <location filename="src/accesspointgui.cpp" line="53"/>
+        <location filename="src/accesspointgui.cpp" line="15"/>
+        <source>No change to MAC</source>
+        <translation>Ne pas changer</translation>
+    </message>
+    <message>
+        <location filename="src/accesspointgui.cpp" line="16"/>
+        <source>Use custom MAC :</source>
+        <translation>MAC personnalisée :</translation>
+    </message>
+    <message>
+        <location filename="src/accesspointgui.cpp" line="17"/>
+        <source>Use a random MAC</source>
+        <translation>MAC aléatoire</translation>
+    </message>
+    <message>
+        <location filename="src/accesspointgui.cpp" line="71"/>
         <source>Invalid key</source>
         <translation>Clé invalide</translation>
     </message>
     <message>
-        <location filename="src/accesspointgui.cpp" line="53"/>
+        <location filename="src/accesspointgui.cpp" line="71"/>
         <source>Keys must have a length of 5 or 13. Your key has been tweaked according to this.</source>
         <translation>Les clés doivent avoir une longueur de 5 ou 13. La clé a été changée selon ce critère.</translation>
     </message>
+    <message>
+        <location filename="src/accesspointgui.cpp" line="101"/>
+        <source>Invalid MAC</source>
+        <translation>MAC invalide</translation>
+    </message>
+    <message>
+        <location filename="src/accesspointgui.cpp" line="101"/>
+        <source>The custom MAC is invalid. It has been reset to the default value.</source>
+        <translation>L&apos;adresse MAC personnalisée est invalide. Elle a été remise à zéro.</translation>
+    </message>
 </context>
 <context>
     <name>AccessPointGUIClass</name>
@@ -22,29 +47,34 @@
         <translation>Hotspot Wifi</translation>
     </message>
     <message>
-        <location filename="src/accesspointgui.ui" line="29"/>
+        <location filename="src/accesspointgui.ui" line="42"/>
         <source>Hotspot name :</source>
         <translation>Nom :</translation>
     </message>
     <message>
-        <location filename="src/accesspointgui.ui" line="49"/>
+        <location filename="src/accesspointgui.ui" line="62"/>
         <source>Security :</source>
         <translation>Sécurité :</translation>
     </message>
     <message>
-        <location filename="src/accesspointgui.ui" line="95"/>
+        <location filename="src/accesspointgui.ui" line="108"/>
         <source>Key :</source>
         <translation>Clé :</translation>
     </message>
     <message>
-        <location filename="src/accesspointgui.ui" line="75"/>
+        <location filename="src/accesspointgui.ui" line="88"/>
         <source>Enable WEP encryption</source>
         <translation>Activer le cryptage WEP</translation>
     </message>
     <message>
-        <location filename="src/accesspointgui.ui" line="138"/>
-        <source>Reset the Wifi driver at startup/shutdown</source>
-        <oldsource>Reset the Wifi driver on startup/shutdown</oldsource>
+        <location filename="src/accesspointgui.ui" line="132"/>
+        <source>MAC address :</source>
+        <translation>Adresse MAC :</translation>
+    </message>
+    <message>
+        <location filename="src/accesspointgui.ui" line="168"/>
+        <source>Restart the Wifi driver at startup/shutdown</source>
+        <oldsource>Reset the Wifi driver at startup/shutdown</oldsource>
         <translation>Redémarrer le driver Wifi à l&apos;activation / arrêt</translation>
     </message>
     <message>
@@ -56,29 +86,33 @@
 <context>
     <name>InternetAccessGUI</name>
     <message>
+        <location filename="src/internetaccessgui.cpp" line="22"/>
         <source>No change</source>
-        <translation type="obsolete">Ne pas changer</translation>
+        <translation>Ne pas changer</translation>
     </message>
     <message>
+        <location filename="src/internetaccessgui.cpp" line="23"/>
         <source>2G only</source>
-        <translation type="obsolete">2G seulement</translation>
+        <translation>2G seulement</translation>
     </message>
     <message>
+        <location filename="src/internetaccessgui.cpp" line="24"/>
         <source>3G only</source>
-        <translation type="obsolete">3G seulement</translation>
+        <translation>3G seulement</translation>
     </message>
     <message>
+        <location filename="src/internetaccessgui.cpp" line="25"/>
         <source>2G/3G</source>
         <oldsource>2G &amp; 3G</oldsource>
-        <translation type="obsolete">2G/3G</translation>
+        <translation>2G/3G</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="187"/>
+        <location filename="src/internetaccessgui.cpp" line="207"/>
         <source>Invalid network</source>
         <translation>Réseau invalide</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="187"/>
+        <location filename="src/internetaccessgui.cpp" line="207"/>
         <source>The entered network is invalid. The default value will be used.</source>
         <translation>Le réseau indiqué est invalide. La valeur par défaut sera utilisée.</translation>
     </message>
@@ -91,28 +125,30 @@
         <translation>Réseau</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.ui" line="46"/>
+        <location filename="src/internetaccessgui.ui" line="44"/>
         <source>APN : </source>
         <oldsource>APN name : </oldsource>
         <translation>APN :</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.ui" line="118"/>
+        <location filename="src/internetaccessgui.ui" line="80"/>
+        <source>2G/3G switcher :</source>
+        <oldsource>2G/3G switcher : </oldsource>
+        <translation>Switch 2G/3G :</translation>
+    </message>
+    <message>
+        <location filename="src/internetaccessgui.ui" line="139"/>
         <source>LAN IP (/24) :</source>
         <oldsource>Network IP (/24) :</oldsource>
         <translation>IP LAN (/24) :</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.ui" line="98"/>
+        <location filename="src/internetaccessgui.ui" line="119"/>
         <source>Share internet access</source>
         <translation>Partage internet</translation>
     </message>
     <message>
-        <source>2G/3G switcher :</source>
-        <translation type="obsolete">Switch 2G/3G :</translation>
-    </message>
-    <message>
-        <location filename="src/internetaccessgui.ui" line="65"/>
+        <location filename="src/internetaccessgui.ui" line="63"/>
         <source>Refresh</source>
         <translation>Actualiser</translation>
     </message>
@@ -178,14 +214,13 @@
         <translation type="obsolete">A propos...</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="178"/>
+        <location filename="src/mobilehotspotgui.cpp" line="296"/>
         <source>WEP</source>
         <translation>WEP</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="178"/>
         <source>No encryption</source>
-        <translation>Non-crypté</translation>
+        <translation type="obsolete">Non-crypté</translation>
     </message>
     <message>
         <source>2G only</source>
@@ -200,142 +235,214 @@
         <translation type="obsolete">Sans économie d&apos;énergie</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="180"/>
-        <source>Reset Wifi driver</source>
-        <oldsource>Reset WLAN driver</oldsource>
+        <location filename="src/mobilehotspotgui.cpp" line="308"/>
+        <source>Restart Wifi driver</source>
+        <oldsource>Reset Wifi driver</oldsource>
         <translation>Redémarrage du driver Wifi</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="316"/>
         <source>2G</source>
-        <translation type="obsolete">2G</translation>
+        <translation>2G</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="318"/>
         <source>3G</source>
-        <translation type="obsolete">3G</translation>
+        <translation>3G</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="320"/>
         <source>2G/3G</source>
         <oldsource>2G &amp; 3G</oldsource>
-        <translation type="obsolete">2G/3G</translation>
+        <translation>2G/3G</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="185"/>
+        <location filename="src/mobilehotspotgui.cpp" line="325"/>
         <source>With internet</source>
         <translation>Avec internet</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="185"/>
+        <location filename="src/mobilehotspotgui.cpp" line="325"/>
         <source>Without internet</source>
         <translation>Sans internet</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="189"/>
+        <location filename="src/mobilehotspotgui.cpp" line="329"/>
         <source>Wifi</source>
         <translation>Wifi</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="190"/>
+        <location filename="src/mobilehotspotgui.cpp" line="330"/>
         <source>USB</source>
         <translation>USB</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="198"/>
         <source>USB For Windows Setup</source>
-        <translation type="obsolete">Assistant USB pour Windows</translation>
+        <translation>Assistant USB pour Windows</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="205"/>
         <source>This will help you into installing the USB networking driver into Windows. Please disconnect your N900 from your computer before continuing.</source>
-        <translation type="obsolete">Ceci vous aidera à installer le driver réseau USB pour Windows. Veuillez déconnecter votre N900 du PC avant de continuer.</translation>
+        <translation>Ceci vous aidera à installer le driver réseau USB pour Windows. Veuillez déconnecter votre N900 du PC avant de continuer.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="209"/>
         <source>First, ensure that you have copied the windows-usb-driver folder from /opt/qtmobilehotspot/docs (or QtMobileHotspot-Driver when connected in mass-storage mode) to your computer. If this is not the case, stop this assistant, and copy the folder.</source>
         <oldsource>First, ensure that you have copied the windows-usb-driver folder from /opt/qtmobilehotspot/docs (or QtMobileHotspot-Driver when connected via USB) to your computer. If this is not the case, stop this assistant, and copy the driver.</oldsource>
-        <translation type="obsolete">D&apos;abord, vous devez avoir copié le dossier windows-usb-driver depuis /opt/qtmobilehotspot/docs (ou QtMobileHotspot-Driver quand vous êtes connecté en mode stockage de masse) sur votre ordinateur. Si ce n&apos;est pas le cas, veuillez fermer cet assistant, le faire, et recommencer.</translation>
+        <translation>D&apos;abord, vous devez avoir copié le dossier windows-usb-driver depuis /opt/qtmobilehotspot/docs (ou QtMobileHotspot-Driver quand vous êtes connecté en mode stockage de masse) sur votre ordinateur. Si ce n&apos;est pas le cas, veuillez fermer cet assistant, le faire, et recommencer.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="213"/>
         <source>We are now going to unload every USB module and load the one for USB networking. Ensure that you are disconnected from your PC and that your N900 isn&apos;t in any USB mode (no PC-Suite, no mass-storage).</source>
-        <translation type="obsolete">Nous allons décharger tous les modules USB et charger celui du réseau USB. Vérifiez que vous êtes déconnecté de votre PC et qu&apos;aucun mode USB n&apos;est actif (ni PC-Suite, ni stockage de masse).</translation>
+        <translation>Nous allons décharger tous les modules USB et charger celui du réseau USB. Vérifiez que vous êtes déconnecté de votre PC et qu&apos;aucun mode USB n&apos;est actif (ni PC-Suite, ni stockage de masse).</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="220"/>
         <source>It seems that the USB device is busy. Usually it is due to a USB-mode being active (mass storage / pc-suite). Please stop this mode and try again.</source>
-        <translation type="obsolete">Le port USB est occupé. C&apos;est en général dû à un mode USB actif (stockage de masse / pc-suite). Veuillez arrêter ce mode et recommencer.</translation>
+        <translation>Le port USB est occupé. C&apos;est en général dû à un mode USB actif (stockage de masse / pc-suite). Veuillez arrêter ce mode et recommencer.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="225"/>
         <source>The system failed to load the standard g_ether USB module. It may be due to a missing power-kernel or to a system in an inconsistent state. Please try again later.</source>
-        <translation type="obsolete">Le N900 n&apos;a pas pu charger le driver g_ether. Cela peut être dû à un power-kernel manquant ou à un état inconsistant du système. Réessayez plus tard.</translation>
+        <translation>Le N900 n&apos;a pas pu charger le driver g_ether. Cela peut être dû à un power-kernel manquant ou à un état inconsistant du système. Réessayez plus tard.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="230"/>
         <source>The system failed to turn on the USB interface. It may be due to a system in an inconsistent state, please try again later.</source>
-        <translation type="obsolete">Le N900 n&apos;a pas pu démarrer l&apos;interface USB. Ceci peut être dû à un système dans un état inconsistant. Veuillez réessayer plus tard.</translation>
+        <translation>Le N900 n&apos;a pas pu démarrer l&apos;interface USB. Ceci peut être dû à un système dans un état inconsistant. Veuillez réessayer plus tard.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="235"/>
         <source>Everything seems to be fine on your N900. You can now connect it to your computer, then continue. Do not select any USB-mode when asked.</source>
-        <translation type="obsolete">Tout est prêt côté N900. Vous pouvez maintenant le connecter au PC. Ne sélectionnez aucun mode USB quand demandé.</translation>
+        <translation>Tout est prêt côté N900. Vous pouvez maintenant le connecter au PC. Ne sélectionnez aucun mode USB quand demandé.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="239"/>
         <source>Are you running Windows 7 / Windows Vista ?</source>
-        <translation type="obsolete">Utilisez-vous Windows 7 / Windows Vista ?</translation>
+        <translation>Utilisez-vous Windows 7 / Windows Vista ?</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="241"/>
         <source>The computer will ask you about drivers. Tell it that you want to do an expert install (pick the driver yourself).</source>
-        <translation type="obsolete">L&apos;ordinateur devra installer un nouveau driver. Dites-lui de faire une installation en mode expert (choisir le driver soit-même).</translation>
+        <translation>L&apos;ordinateur devra installer un nouveau driver. Dites-lui de faire une installation en mode expert (choisir le driver soit-même).</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="245"/>
         <source>Now edit the settings in order to make Windows use your windows-usb-driver folder. Make sure not to forget any useful checkbox.</source>
-        <translation type="obsolete">Editez les paramètres afin que Windows cherche dans le dossier windows-usb-driver. N&apos;oubliez aucune case à cocher utile.</translation>
+        <translation>Editez les paramètres afin que Windows cherche dans le dossier windows-usb-driver. N&apos;oubliez aucune case à cocher utile.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="250"/>
         <source>The computer will try to install a driver automatically (usually). It will fail, that is normal.</source>
-        <translation type="obsolete">L&apos;ordinateur va tenter d&apos;installer un driver automatiquement (normalement). Ceci va échouer, c&apos;est normal.</translation>
+        <translation>L&apos;ordinateur va tenter d&apos;installer un driver automatiquement (normalement). Ceci va échouer, c&apos;est normal.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="254"/>
         <source>Now go to the device manager (control panel, system, device manager). You should see an unknown device called Linux Ethernet RNDIS. Right-click on it, and choose Update driver.</source>
-        <translation type="obsolete">A présent rendez-vous dans le gestionnaire de périphériques (panneau config, système, gestion périphériques). Vous devriez voir un périphérique inconnu appelé Linux Ethernet RNDIS. Faites un clic droit dessus, et choisissez Mettre à jour le pilote.</translation>
+        <translation>A présent rendez-vous dans le gestionnaire de périphériques (panneau config, système, gestion périphériques). Vous devriez voir un périphérique inconnu appelé Linux Ethernet RNDIS. Faites un clic droit dessus, et choisissez Mettre à jour le pilote.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="258"/>
         <source>Choose to pick the driver yourself, and tell the program about your windows-usb-driver folder. Do not miss any important checkbox.</source>
-        <translation type="obsolete">Choisissez de trouver vous même le driver à utiliser, et indiquez au programme l&apos;emplacement de votre dossier windows-usb-driver. N&apos;oubliez pas de cocher les cases qui vous concernent.</translation>
+        <translation>Choisissez de trouver vous même le driver à utiliser, et indiquez au programme l&apos;emplacement de votre dossier windows-usb-driver. N&apos;oubliez pas de cocher les cases qui vous concernent.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="263"/>
         <source>Your computer will now install the USB networking driver. If everything goes fine, congratulations, you have a new network device available in the devices-list.</source>
-        <translation type="obsolete">L&apos;ordinateur installe maintenant le driver, patientez. Si tout se passe bien bravo, vous avez une nouvelle carte réseau dans votre liste.</translation>
+        <translation>L&apos;ordinateur installe maintenant le driver, patientez. Si tout se passe bien bravo, vous avez une nouvelle carte réseau dans votre liste.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="267"/>
         <source>You are now ready to use the program in USB mode with your Windows. Just remember to never use pc-suite/mass-storage modes when you enable USB networking.</source>
-        <translation type="obsolete">Vous êtes prêt à utiliser le programme en mode USB avec Windows. Rappelez-vous de ne jamais utiliser la navigation USB en mode PC-Suite ou stockage de masse.</translation>
+        <translation>Vous êtes prêt à utiliser le programme en mode USB avec Windows. Rappelez-vous de ne jamais utiliser la navigation USB en mode PC-Suite ou stockage de masse.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="271"/>
         <source>Windows should not need more configuration in order to be used with qtmobilehotspot. Simply run qtmobilehotspot, start in USB mode, plug your N900 into your PC, and enjoy.</source>
-        <translation type="obsolete">Windows ne devrait plus avoir besoin de configuration supplémentaire. Lancez qtmobilehotspot, démarrez en mode USB, branchez le N900 au PC, et amusez-vous.</translation>
+        <translation>Windows ne devrait plus avoir besoin de configuration supplémentaire. Lancez qtmobilehotspot, démarrez en mode USB, branchez le N900 au PC, et amusez-vous.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="275"/>
         <source>Please note that if you are already using MADDE on your computer, you may have to reset your new network card settings to automatic.</source>
-        <translation type="obsolete">Notez que si vous utilisez déjà MADDE sur votre ordinateur, vous pouvez avoir à modifier les paramètres de la nouvelle carte réseau en automatique.</translation>
+        <translation>Notez que si vous utilisez déjà MADDE sur votre ordinateur, vous pouvez avoir à modifier les paramètres de la nouvelle carte réseau en automatique.</translation>
     </message>
     <message>
+        <location filename="src/mobilehotspotgui.cpp" line="284"/>
         <source>Please disconnect your N900 from your computer. We are going to unload the USB module and load the normal Nokia one. Do not choose any USB mode if you plan to use qtmobilehotspot.</source>
-        <translation type="obsolete">Veuillez débrancher le N900 du PC. Nous allons décharger le module USB et recharger le module Nokia normal. Ne choisissez aucun mode USB si vous prévoyez d&apos;utiliser qtmobilehotspot.</translation>
+        <translation>Veuillez débrancher le N900 du PC. Nous allons décharger le module USB et recharger le module Nokia normal. Ne choisissez aucun mode USB si vous prévoyez d&apos;utiliser qtmobilehotspot.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="261"/>
+        <location filename="src/mobilehotspotgui.cpp" line="296"/>
+        <source>Open</source>
+        <translation>Ouvert</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="300"/>
+        <source>Custom MAC</source>
+        <translation>MAC perso</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="306"/>
+        <source>Random MAC</source>
+        <translation>MAC aléatoire</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="410"/>
         <source>Error : LAN and Internet are both using the Wifi interface, please use a LAN on USB</source>
         <translation>Erreur : Le LAN et Internet sont tous deux sur l&apos;interface Wifi, veuillez utiliser un LAN sur USB</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="262"/>
+        <location filename="src/mobilehotspotgui.cpp" line="411"/>
         <source>Cannot start</source>
         <translation>Impossible de démarrer</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="329"/>
+        <location filename="src/mobilehotspotgui.cpp" line="439"/>
+        <source>Error while loading system modules using a plugin</source>
+        <translation>Erreur au chargement des modules système avec un plugin</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="488"/>
+        <source>Error while loading USB module using a plugin</source>
+        <translation>Erreur au chargement du module USB avec un plugin</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="498"/>
         <source>Error : USB shouldn&apos;t be in any mode (no storage mode, no pc-suite mode)</source>
         <translation>Erreur : Aucun mode USB ne devrait être actif (ni stockage de masse, ni PC-Suite)</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="334"/>
+        <location filename="src/mobilehotspotgui.cpp" line="503"/>
         <source>Error while loading standard g_ether driver</source>
         <oldsource>Error while switching from nokia&apos;s modules to standard ones</oldsource>
         <translation>Erreur au chargement du driver g_ether</translation>
     </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="511"/>
+        <source>Error while preparing the USB interface using a plugin</source>
+        <translation>Erreur à la préparation de l&apos;interface USB avec un plugin</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="544"/>
+        <source>Error while starting DNS/DHCP server using a plugin</source>
+        <translation>Erreur au lancement du serveur DNS/DHCP avec un plugin</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="551"/>
+        <source>Error while starting dnsmasq</source>
+        <translation>Erreur au lancement du serveur DNS/DHCP dnsmasq</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="559"/>
+        <source>Error while setting iptables using a plugin</source>
+        <translation>Erreur lors de la mise en place des iptables avec un plugin</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="565"/>
+        <source>Error while setting iptables</source>
+        <translation>Erreur lors de la mise en place des iptables</translation>
+    </message>
     <message>
         <source>Hotspot stopped</source>
         <translation type="obsolete">Hotspot arrêté</translation>
@@ -345,18 +452,18 @@
         <translation type="obsolete">Paramètres invalides</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="286"/>
+        <location filename="src/mobilehotspotgui.cpp" line="446"/>
         <source>Error while loading system modules, are you running the power kernel ?</source>
         <translation>Erreur au chargement des modules système. Utilisez-vous le power-kernel ?</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="299"/>
-        <location filename="src/mobilehotspotgui.cpp" line="311"/>
+        <location filename="src/mobilehotspotgui.cpp" line="460"/>
+        <location filename="src/mobilehotspotgui.cpp" line="472"/>
         <source>Error while disconnecting previous internet connection</source>
         <translation>Erreur à la désactivation de la connection internet</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="304"/>
+        <location filename="src/mobilehotspotgui.cpp" line="465"/>
         <source>Error while connecting to the APN, you way need to select it again in the Networking panel</source>
         <oldsource>Error while connecting to the chosen APN</oldsource>
         <translation>Erreur à la connection à l&apos;APN choisi, essayez de le re-sélectionner dans la configuration réseau</translation>
@@ -370,12 +477,17 @@
         <translation type="obsolete">Erreur lors du passage de g_nokia vers g_ether</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="339"/>
+        <location filename="src/mobilehotspotgui.cpp" line="517"/>
         <source>Error while preparing the USB interface</source>
         <translation>Erreur à la préparation de l&apos;interface USB</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="347"/>
+        <location filename="src/mobilehotspotgui.cpp" line="528"/>
+        <source>Error while preparing the Wifi interface using a plugin</source>
+        <translation>Erreur à la préparation de l&apos;interface Wifi avec un plugin</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="534"/>
         <source>Error while preparing the Wifi interface</source>
         <translation>Erreur à la préparation de l&apos;interface Wifi</translation>
     </message>
@@ -384,7 +496,7 @@
         <translation type="obsolete">Erreur (timeout) à l&apos;arrêt du serveur DNS/DHCP</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="368"/>
+        <location filename="src/mobilehotspotgui.cpp" line="574"/>
         <source>Failed to start the hotspot</source>
         <translation>Echec du démarrage du hotspot</translation>
     </message>
@@ -397,17 +509,17 @@
         <translation type="obsolete">Sans économie d&apos;énergie</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="387"/>
+        <location filename="src/mobilehotspotgui.cpp" line="607"/>
         <source>Hotspot started successfully</source>
         <translation>Hotspot démarré avec succès</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="551"/>
+        <location filename="src/mobilehotspotgui.cpp" line="850"/>
         <source>Hotspot stopped successfully</source>
         <translation>Hotspot arrêté avec succès</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="551"/>
+        <location filename="src/mobilehotspotgui.cpp" line="850"/>
         <source>Hotspot stopped with errors</source>
         <translation>Hotspot arrêté avec erreurs</translation>
     </message>
@@ -430,7 +542,7 @@
         <translation>Arrêter</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.ui" line="243"/>
+        <location filename="src/mobilehotspotgui.ui" line="244"/>
         <source>Language...</source>
         <translation>Langue...</translation>
     </message>
@@ -440,12 +552,12 @@
         <translation>Fichier</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.ui" line="233"/>
+        <location filename="src/mobilehotspotgui.ui" line="234"/>
         <source>USB For Windows Setup</source>
         <translation>USB pour Windows</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.ui" line="238"/>
+        <location filename="src/mobilehotspotgui.ui" line="239"/>
         <source>Plugins...</source>
         <translation>Plugins...</translation>
     </message>
@@ -474,7 +586,7 @@
         <translation>Plugins</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.ui" line="228"/>
+        <location filename="src/mobilehotspotgui.ui" line="229"/>
         <source>About Qt Mobile Hotspot</source>
         <oldsource>About qtMobileHotspot</oldsource>
         <translation>A propos de Qt Mobile Hotspot</translation>
