@@ -11,6 +11,10 @@ AccessPointGUI::AccessPointGUI(QWidget *parent)
 {
 	ui.setupUi(this);
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
+	ui.lstMAC->addItem(tr("No change to MAC"));
+	ui.lstMAC->addItem(tr("Use custom MAC :"));
+	ui.lstMAC->addItem(tr("Use a random MAC"));
 }
 
 AccessPointGUI::~AccessPointGUI()
@@ -30,6 +34,13 @@ void AccessPointGUI::setConfiguration(MobileHotspotConfiguration &configuration)
 	ui.txtAPName->setText(configuration.hotspotName);
 	ui.chkEncryption->setChecked(configuration.encryptionType == configuration.ENCRYPTION_WEP);
 	ui.txtKey->setText(configuration.encryptionKey);
+	if(configuration.wlanTypeMAC == MAC_NORMAL)
+		ui.lstMAC->setCurrentIndex(0);
+	else if(configuration.wlanTypeMAC == MAC_CUSTOM)
+		ui.lstMAC->setCurrentIndex(1);
+	else
+		ui.lstMAC->setCurrentIndex(2);
+	ui.txtMAC->setText(configuration.wlanCustomMAC);
 	ui.chkWLANDriver->setChecked(configuration.cycleWlanDriver);
 }
 
@@ -38,6 +49,13 @@ void AccessPointGUI::configuration(MobileHotspotConfiguration *configuration){
 	configuration->hotspotName = name == "" ? "N900 Hotspot" : name;
 	configuration->encryptionType = ui.chkEncryption->isChecked() ? configuration->ENCRYPTION_WEP : configuration->ENCRYPTION_NONE;
 	configuration->encryptionKey = validKey();
+	if(ui.lstMAC->currentIndex() == 0)
+		configuration->wlanTypeMAC = MAC_NORMAL;
+	else if(ui.lstMAC->currentIndex() == 1)
+		configuration->wlanTypeMAC = MAC_CUSTOM;
+	else
+		configuration->wlanTypeMAC = MAC_RANDOM;
+	configuration->wlanCustomMAC = validMAC();
 	configuration->cycleWlanDriver = ui.chkWLANDriver->isChecked();
 }
 
@@ -60,3 +78,27 @@ QString AccessPointGUI::validKey(){
 	}
 	return res;
 }
+
+QString AccessPointGUI::validMAC(){
+	QString mac = ui.txtMAC->text();
+	try{
+		QStringList parts = mac.split(":");
+		if(parts.size() != 6)
+			throw QString();
+		for(int i = 0; i < 6; i++){
+			QString part = parts.at(i);
+			if(part.size() != 2)
+				throw QString();
+			for(int j = 0; j < part.size(); j++){
+				QChar digit = part.at(j);
+				if( (digit < '0' || digit > '9') && (digit < 'a' || digit > 'f') )
+					throw QString();
+			}
+		}
+		return mac;
+	}
+	catch(QString fail){
+		QMessageBox::warning(this, tr("Invalid MAC"), tr("The custom MAC is invalid. It has been reset to the default value."));
+		return "02:11:22:33:44:55";
+	}
+}
