@@ -91,7 +91,7 @@ int DBUSHelper::cellInternetAvailable(bool *available){
 	return ok ? 0 : -1;
 }
 
-int DBUSHelper::internetEnforcement2G3G(Enforcement2G3G *enforcement){
+int DBUSHelper::internetEnforcement2G3G(DBUS_Enforcement2G3G *enforcement){
 	/* -1=fail, 0=ok */
 	QDBusMessage msg = QDBusMessage::createMethodCall("com.nokia.phone.net", "/com/nokia/phone/net", "Phone.Net", "get_selected_radio_access_technology");
 	QDBusMessage msg2 = QDBusConnection::systemBus().call(msg);
@@ -116,7 +116,7 @@ int DBUSHelper::internetEnforcement2G3G(Enforcement2G3G *enforcement){
 	return ok ? 0 : -1;
 }
 
-int DBUSHelper::setInternetEnforcement2G3G(Enforcement2G3G enforcement){
+int DBUSHelper::setInternetEnforcement2G3G(DBUS_Enforcement2G3G enforcement){
 	/* -1=fail, 0=ok */
 	QDBusMessage msg = QDBusMessage::createMethodCall("com.nokia.phone.net", "/com/nokia/phone/net", "Phone.Net", "set_selected_radio_access_technology");
 	QList<QVariant> args;
