@@ -5,7 +5,7 @@
 #include <QtDBus/QDBusMessage>
 
 
-enum Enforcement2G3G{
+enum DBUS_Enforcement2G3G{
 	DBUS_2G3G_2G,
 	DBUS_2G3G_3G,
 	DBUS_2G3G_DOUBLE
@@ -24,8 +24,8 @@ public:
     static int internetDisconnect();
     static int internetConnect(QString IAP_ID);
     static int cellInternetAvailable(bool *available);
-    static int internetEnforcement2G3G(Enforcement2G3G *enforcement);
-    static int setInternetEnforcement2G3G(Enforcement2G3G enforcement);
+    static int internetEnforcement2G3G(DBUS_Enforcement2G3G *enforcement);
+    static int setInternetEnforcement2G3G(DBUS_Enforcement2G3G enforcement);
     static int internetConnectionsCount();
 };
 
