@@ -1,4 +1,5 @@
 #include <QtCore/QString>
+#include <QtCore/QDateTime>
 #include <QtCore/QStringList>
 #include <QtCore/QListIterator>
 #include <QtCore/QByteArray>
@@ -153,7 +154,7 @@ int HotspotHelper::prepareUSBInterface(QString usbMAC, QString lanNetwork){
 
 	/** Change USB MAC if necessary **/
 	if(usbMAC != ""){
-		ret = setUSBMAC(usbMAC);
+		ret = setInterfaceMAC(MobileHotspotConfiguration::INTERFACE_USB, usbMAC);
 		if(ret == -2){
 			qDebug("Error (timeout) while changing the USB MAC");
 			return -1;
@@ -172,34 +173,63 @@ int HotspotHelper::prepareUSBInterface(QString usbMAC, QString lanNetwork){
 	return 0;
 }
 
-int HotspotHelper::setUSBMAC(QString usbMAC){
+int HotspotHelper::setInterfaceMAC(QString interface, QString mac){
 	/* -1=fail, -2=timeout, 0=ok */
-	qDebug("*** Changing USB MAC ***");
+	qDebug("*** Changing MAC ***");
 	int ret, tries;
 	bool cmdret, trying;
-	QString cmd("/sbin/ifconfig "); cmd += MobileHotspotConfiguration::INTERFACE_USB; cmd += " hw ether "; cmd += usbMAC;
+	QString cmd("/sbin/ifconfig "); cmd += interface; cmd += " hw ether "; cmd += mac;
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
-		qDebug("FAILURE : Cannot change USB MAC");
+		qDebug("FAILURE : Cannot change MAC");
 		return -1;
 	}
 	trying = true; tries = 0;
 	while(trying && tries < MAX_TRIES){
 		tries++;
 		QString res;
-		CommandHelper::executeCommandWithStdOut(QString("/sbin/ifconfig ") + MobileHotspotConfiguration::INTERFACE_USB, &ret, &res);
-		if(res.toLower().count(usbMAC.toLower()) > 0)
+		CommandHelper::executeCommandWithStdOut(QString("/sbin/ifconfig ") + interface, &ret, &res);
+		if(res.toLower().count(mac.toLower()) > 0)
 			trying = false;
 		else
 			CommandHelper::executeCommand("sleep 1");
 	}
 	if(trying){
-		qDebug("FAILURE : System was too slow changing USB MAC");
+		qDebug("FAILURE : System was too slow changing MAC");
 		return -2;
 	}
 	return 0;
 }
 
+int HotspotHelper::getInterfaceMAC(QString interface, QString *mac){
+	/* -1=fail, 0=ok */
+	qDebug("*** Getting MAC ***");
+	bool res;
+	int ret;
+	QString stdout;
+	res = CommandHelper::executeCommandWithStdOut("/bin/sh -c \"ifconfig " + interface + " | grep -o -E '([[:xdigit:]]{1,2}:){5}[[:xdigit:]]{1,2}'\"" , &ret, &stdout);
+	if( (! res) || ret != 0){
+		qDebug("FAILURE : Cannot get MAC");
+		return -1;
+	}
+	*mac = stdout.trimmed();
+	return 0;
+}
+
+QString HotspotHelper::randomMAC(){
+	QString result("02:");
+	qsrand(QDateTime::currentDateTime().toTime_t());
+	for(int i = 0; i < 5; i++){
+		if(i > 0)
+			result += ":";
+		int number1 = qrand() % 16;
+		int number2 = qrand() % 16;
+		result += QString("%1").arg(number1, 0, 16);
+		result += QString("%1").arg(number2, 0, 16);
+	}
+	result = result.toLower();
+	return result;
+}
 
 int HotspotHelper::checkUSBMode(){
 	/* -1=fail, 0=ok */
@@ -314,7 +344,7 @@ int HotspotHelper::enableUSBInterface(QString lanNetwork){
 	return 0;
 }
 
-int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuration){
+int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuration, QString *oldMAC){
 	/* -1=fail, 0=ok */
 	qDebug("** Preparing Wifi interface **");
 	int ret;
@@ -337,6 +367,20 @@ int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuratio
 		}
 	}
 
+	/** Save MAC address **/
+	ret = getInterfaceMAC(configuration.INTERFACE_WLAN, oldMAC);
+	if(ret != 0)
+		qDebug("WARNING : Was not able to save the WLAN MAC");
+
+	/** MAC changing if needed **/
+	if(configuration.wlanTypeMAC != MAC_NORMAL){
+		ret = setInterfaceMAC(configuration.INTERFACE_WLAN, configuration.wlanTypeMAC == MAC_CUSTOM ? configuration.wlanCustomMAC : randomMAC());
+		if(ret != 0){
+			qDebug("Error while changing the WLAN MAC");
+			return -1;
+		}
+	}
+
 	/** Power saving - May not work on adhoc, but who knows **/
 	/** Switch to managed mode (to be able to change power management) - may fail, not fatal unless timeout **/
 	ret = setAdhocMode(configuration, false);
@@ -654,7 +698,7 @@ int HotspotHelper::unprepareUSBInterface(){
 	return res;
 }
 
-int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configuration){
+int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configuration, QString &oldMAC){
 	/** -1=fail, 0=ok */
 	qDebug("** Unpreparing Wifi interface **");
 	int res = 0, ret;
@@ -701,6 +745,15 @@ int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configurat
 		}
 	}
 
+	if(configuration.wlanTypeMAC != MAC_NORMAL){
+		/** Restore original MAC **/
+		ret = setInterfaceMAC(configuration.INTERFACE_WLAN, oldMAC);
+		if(ret != 0){
+			qDebug("Error while restoring WLAN MAC");
+			res = -1;
+		}
+	}
+
 	return res;
 }
 
@@ -709,13 +762,10 @@ int HotspotHelper::cycleWLANDriver(MobileHotspotConfiguration &configuration){
 	qDebug("** Unloading/reloading WLAN driver **");
 	int ret;
 	bool res;
-	QString mac;
-	QString cmd = QString("/bin/sh -c \"ifconfig ") + configuration.lanInterface + " | grep -o -E '([[:xdigit:]]{1,2}:){5}[[:xdigit:]]{1,2}'\"";
-	res = CommandHelper::executeCommandWithStdOut(cmd , &ret, &mac);
-	mac = mac.trimmed();
-	if( (! res) || (ret != 0) )
+	QString mac = ":";
+	if(getInterfaceMAC(configuration.INTERFACE_WLAN, &mac) != 0)
 		qDebug("WARNING : Was not able to get WLAN MAC address, it may change without us being able to restore it");
-	cmd = "rmmod wl12xx";
+	QString cmd = "rmmod wl12xx";
 	res = CommandHelper::executeCommand(cmd , &ret);
 	if( (! res) || (ret != 0) )
 		qDebug("WARNING : Was not able to remove wl12xx module");
