@@ -28,9 +28,9 @@ public:
     static int loadNokiaUSB();
     static void unloadNokiaUSB();
     static int prepareUSBInterface(QString usbMAC, QString lanNetwork);
-    static int prepareWifiInterface(MobileHotspotConfiguration &configuration);
+    static int prepareWifiInterface(MobileHotspotConfiguration &configuration, QString *oldMAC);
     static int unprepareUSBInterface();
-    static int unprepareWifiInterface(MobileHotspotConfiguration &configuration);
+    static int unprepareWifiInterface(MobileHotspotConfiguration &configuration, QString &oldMAC);
     static int startDnsMasq(MobileHotspotConfiguration &configuration, QProcess *dnsmasqProcess);
     static int stopDnsMasq(MobileHotspotConfiguration &configuration, QProcess *dnsmasqProcess);
     static int setIPTables(MobileHotspotConfiguration &configuration, int *ipforward);
@@ -41,7 +41,9 @@ private:
 	static int unloadModule(QString moduleName);
 	static QStringList getSystemModules();
 	static int enableUSBInterface(QString lanNetwork);
-	static int setUSBMAC(QString usbMAC);
+	static int getInterfaceMAC(QString interface, QString *mac);
+	static int setInterfaceMAC(QString interface, QString mac);
+	static QString randomMAC();
 	static int disableUSBInterface();
 	static int enableWifiInterface(MobileHotspotConfiguration &configuration);
 	static int disableWifiInterface(MobileHotspotConfiguration &configuration);
