@@ -19,6 +19,10 @@ InternetAccessGUI::InternetAccessGUI(QWidget *parent)
 {
 	ui.setupUi(this);
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+	ui.lst2G3G->addItem(tr("No change"), "ignore");
+	ui.lst2G3G->addItem(tr("2G only"), "2g");
+	ui.lst2G3G->addItem(tr("3G only"), "3g");
+	ui.lst2G3G->addItem(tr("2G/3G"), "2g3g");
 
 	waitingForAPNs = false;
 	gprsOnly = false;
@@ -48,6 +52,14 @@ void InternetAccessGUI::closeEvent(QCloseEvent* event){
 void InternetAccessGUI::setConfiguration(MobileHotspotConfiguration &configuration){
 	ui.txtNetwork->setText(configuration.lanNetwork + "0");
 	ui.chkInternet->setChecked(configuration.internetEnabled);
+	if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_IGNORE)
+		ui.lst2G3G->setCurrentIndex(0);
+	else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_2G)
+		ui.lst2G3G->setCurrentIndex(1);
+	else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_3G)
+		ui.lst2G3G->setCurrentIndex(2);
+	else
+		ui.lst2G3G->setCurrentIndex(3);
 
 	gprsOnly = configuration.lanInterface == configuration.INTERFACE_WLAN;
 	currentIAPID = configuration.internetAPID;
@@ -85,6 +97,14 @@ void InternetAccessGUI::configuration(MobileHotspotConfiguration *configuration)
 	}
 	configuration->lanNetwork = validNetwork();
 	configuration->internetEnabled = ui.chkInternet->isChecked();
+	if(ui.lst2G3G->currentIndex() == 0)
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_IGNORE;
+	else if(ui.lst2G3G->currentIndex() == 1)
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_2G;
+	else if(ui.lst2G3G->currentIndex() == 2)
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_3G;
+	else
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_DOUBLE;
 }
 
 void InternetAccessGUI::apnsDisableSignal(){
