@@ -3,7 +3,8 @@
 
 #define TIME_APNS ((int)2500)
 
-#include <QtGui/QDialog>
+#include <QtGui/QMainWindow>
+#include <QtGui/QCloseEvent>
 #include <QtCore/QString>
 #include <QtCore/QList>
 #include <QtCore/QStringList>
@@ -12,7 +13,7 @@
 #include "ui_internetaccessgui.h"
 
 
-class InternetAccessGUI : public QDialog
+class InternetAccessGUI : public QMainWindow
 {
     Q_OBJECT
 
@@ -22,6 +23,9 @@ public:
     void setConfiguration(MobileHotspotConfiguration &configuration);
     void configuration(MobileHotspotConfiguration *configuration);
 
+protected:
+	void closeEvent(QCloseEvent* event);
+
 private:
 	void apnsEnableSignal();
 	void apnsDisableSignal();
@@ -40,6 +44,8 @@ private slots :
 	void apnsTimeout();
 	void updateAPNs();
 
+signals:
+	void windowClosed();
 };
 
 #endif // INTERNETACCESSGUI_H
