@@ -40,8 +40,22 @@ void MobileHotspotConfiguration::load(){
 	encryptionKey = item->value("0000000000000").toString();
 	delete item;
 
+	item = new GConfItem(GCONF_WLANMAC);
+	wlanCustomMAC = item->value("02:11:22:33:44:55").toString();
+	delete item;
+
+	item = new GConfItem(GCONF_WLANMACTYPE);
+	QString wlanmactype = item->value("normal").toString();
+	if(wlanmactype == "custom")
+		wlanTypeMAC = MAC_CUSTOM;
+	else if(wlanmactype == "random")
+		wlanTypeMAC = MAC_RANDOM;
+	else
+		wlanTypeMAC = MAC_NORMAL;
+	delete item;
+
 	item = new GConfItem(GCONF_WLANDRIVER);
-	cycleWlanDriver = item->value("true").toString() == "true";
+	cycleWlanDriver = item->value(false).toBool();
 	delete item;
 
 	item = new GConfItem(GCONF_INTERFACE);
@@ -65,7 +79,19 @@ void MobileHotspotConfiguration::load(){
 	delete item;
 
 	item = new GConfItem(GCONF_INTERNET);
-	internetEnabled = item->value("true").toString() == "true";
+	internetEnabled = item->value(true).toBool();
+	delete item;
+
+	item = new GConfItem(GCONF_2G3G);
+	QString enf = item->value("ignore").toString();
+	if(enf == "2g")
+		enforcement2g3g = ENFORCEMENT_2G3G_2G;
+	else if(enf == "3g")
+		enforcement2g3g = ENFORCEMENT_2G3G_3G;
+	else if(enf == "2g3g")
+		enforcement2g3g = ENFORCEMENT_2G3G_DOUBLE;
+	else
+		enforcement2g3g = ENFORCEMENT_2G3G_IGNORE;
 	delete item;
 
 	loadUSBMAC();
@@ -90,8 +116,21 @@ void MobileHotspotConfiguration::save(){
 	item->set(encryptionKey);
 	delete item;
 
+	item = new GConfItem(GCONF_WLANMAC);
+	item->set(wlanCustomMAC);
+	delete item;
+
+	item = new GConfItem(GCONF_WLANMACTYPE);
+	if(wlanTypeMAC == MAC_CUSTOM)
+		item->set("custom");
+	else if(wlanTypeMAC == MAC_RANDOM)
+		item->set("random");
+	else
+		item->set("normal");
+	delete item;
+
 	item = new GConfItem(GCONF_WLANDRIVER);
-	item->set(cycleWlanDriver ? "true" : "false");
+	item->set(cycleWlanDriver);
 	delete item;
 
 	item = new GConfItem(GCONF_INTERFACE);
@@ -115,7 +154,18 @@ void MobileHotspotConfiguration::save(){
 	delete item;
 
 	item = new GConfItem(GCONF_INTERNET);
-	item->set(internetEnabled ? "true" : "false");
+	item->set(internetEnabled);
+	delete item;
+
+	item = new GConfItem(GCONF_2G3G);
+	if(enforcement2g3g == ENFORCEMENT_2G3G_2G)
+		item->set("2g");
+	else if(enforcement2g3g == ENFORCEMENT_2G3G_3G)
+		item->set("3g");
+	else if(enforcement2g3g == ENFORCEMENT_2G3G_DOUBLE)
+		item->set("2g3g");
+	else
+		item->set("ignore");
 	delete item;
 
 	saveUSBMAC();
