@@ -32,6 +32,7 @@ private:
 	void updateDisplayedConfiguration();
 	void loadPlugins();
 	void sortPlugins();
+	void updateServicesPlugins();
 	void previousConnectionEnableSignal();
 	void previousConnectionDisableSignal();
 	void previousConnectionRequest();
@@ -46,9 +47,12 @@ private:
     QMap<QString, MobileHotspotPlugin*> plugins;
     QList<QString> sortedPlugins;
     QMap<QString, QString> pluginsTranslatorsBaseNames;
+    QMap<QString, MobileHotspotPlugin*> servicesPlugins;
 
     MobileHotspotConfiguration configuration;
 
+    DBUS_Enforcement2G3G previousEnforcement;
+    QString previousWlanMAC;
     QStringList alreadyLoadedModules;
     int scanInterval;
     QProcess *dnsmasqProcess;
@@ -65,6 +69,7 @@ protected :
         void closeEvent(QCloseEvent* event);
 
 private slots:
+	void usbWindowsAssistant();
 	void configureLanguage();
 	void configureLanguageFinished(bool saveConfiguration);
 	void configurePlugins();
