@@ -7,18 +7,29 @@
 #include "mobilehotspotplugin.h"
 
 
+#define GCONF_PLUGIN_ENABLED_SUFFIX ".internal.enabled"
+
+
 class MobileHotspotPluginHelper{
 
 public:
 	MobileHotspotPluginHelper(MobileHotspotPlugin *plug);
 	~MobileHotspotPluginHelper();
-	QString gconfKey();
+
 	void save(QString name, QVariant data);
 	QVariant load(QString name, QVariant def);
+	void deleteConfiguration();
+	void setPluginEnabled(bool enabled);
+	bool isPluginEnabled();
+	void installTranslator();
+	void removeTranslator();
 
 private:
-	MobileHotspotPlugin *plugin;
+	QString gconfKey();
+	QString gconfEnabledKey();
 
+	MobileHotspotPlugin *plugin;
+	bool enabled;
 };
 
 
