@@ -10,16 +10,25 @@ PluginConfiguration::~PluginConfiguration(){
 	// helper deletion is handled by plugin itself, no need to destroy it here
 }
 
+void PluginConfiguration::reset(){
+	// Reset the plugin's configuration, by deleting the saved one and calling load()
+	helper->deleteConfiguration(); // Delete saved configuration
+
+	// You may want to do some things here before calling load, such as freeing memory
+	// Type here your customized code
+	// delete myVariable;
+
+	load(); // Load configuration (the default one, as none is saved)
+}
+
 void PluginConfiguration::load(){
 	// Load the plugin's configuration, please use the helper function load("settingName", "defaultValue")
 	// some_variable = helper->load("settingName", "default value").toString();
-	QString mode = helper->load("mode", "disabled").toString();
+	QString mode = helper->load("mode", "allow").toString();
 	if(mode == "allow")
 		filterMode =  MODE_ALLOW;
-	else if(mode == "deny")
-		filterMode = MODE_DENY;
 	else
-		filterMode = MODE_DISABLED;
+		filterMode = MODE_DENY;
 	mactable = helper->load("mactable", QStringList()).toStringList();
 }
 
@@ -29,10 +38,8 @@ void PluginConfiguration::save(){
 	QString mode;
 	if(filterMode == MODE_ALLOW)
 		mode = "allow";
-	else if(filterMode == MODE_DENY)
-		mode = "deny";
 	else
-		mode = "disabled";
+		mode = "deny";
 	helper->save("mode", mode);
 	helper->save("mactable", mactable);
 }
