@@ -19,8 +19,8 @@ public:
 	~PluginConfiguration();
 	void save();
 	void load();
+	void reset();
 
-	bool enabled;
 	int port;
 	QString ports;
 	UserAgent ua;
