@@ -15,7 +15,7 @@ PrivoxyHelper::PrivoxyHelper(){
 PrivoxyHelper::~PrivoxyHelper(){
 }
 
-int PrivoxyHelper::generateConfigurationFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf){
+int PrivoxyHelper::generateConfigurationFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf){
 	/* 0=ok, -1=fail */
 	qDebug("Generating Privoxy configuration file %s from %s", CONFIGURATION_FILE, CONFIGURATION_FILE_QTMH);
 	int ret;
@@ -27,7 +27,7 @@ int PrivoxyHelper::generateConfigurationFile(const MobileHotspotConfiguration &c
 		return -1;
 	}
 
-	cmd = ((QString("echo \"listen-address ") + configuration.lanNetwork) + "1:") + QString::number(conf->port) + "\"";
+	cmd = ((QString("echo \"listen-address ") + configuration->lanNetwork) + "1:") + QString::number(conf->port) + "\"";
 	cmd += QString(" >> ") + CONFIGURATION_FILE;
 	CommandHelper::executeCommandOld(cmd, &ret);
 	if(ret != 0){
@@ -60,7 +60,7 @@ int PrivoxyHelper::generateConfigurationFile(const MobileHotspotConfiguration &c
 	return 0;
 }
 
-int PrivoxyHelper::deleteConfigurationFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf){
+int PrivoxyHelper::deleteConfigurationFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf){
 	/* 0=ok, -1=fail */
 	qDebug("Deleting Privoxy configuration file %s", CONFIGURATION_FILE);
 	QFile file(CONFIGURATION_FILE);
@@ -69,7 +69,7 @@ int PrivoxyHelper::deleteConfigurationFile(const MobileHotspotConfiguration &con
 	return 0;
 }
 
-int PrivoxyHelper::generateActionFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf){
+int PrivoxyHelper::generateActionFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf){
 	/* 0=ok, -1=fail */
 	qDebug("Generating Privoxy action file %s from %s", ACTION_FILE, ACTION_FILE_QTMH);
 	int ret;
@@ -106,7 +106,7 @@ int PrivoxyHelper::generateActionFile(const MobileHotspotConfiguration &configur
 	return 0;
 }
 
-int PrivoxyHelper::deleteActionFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf){
+int PrivoxyHelper::deleteActionFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf){
 	/* 0=ok, -1=fail */
 	qDebug("Deleting Privoxy action file %s", ACTION_FILE);
 	QFile file(ACTION_FILE);
@@ -115,7 +115,7 @@ int PrivoxyHelper::deleteActionFile(const MobileHotspotConfiguration &configurat
 	return 0;
 }
 
-int PrivoxyHelper::runPrivoxy(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf, QProcess *process){
+int PrivoxyHelper::runPrivoxy(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf, QProcess *process){
 	/* 0=ok, -1=fail */
 	qDebug("Running Privoxy %s", PRIVOXY_FILE);
 	QString cmd = (QString(PRIVOXY_FILE) + " --no-daemon ") + CONFIGURATION_FILE;
@@ -123,21 +123,20 @@ int PrivoxyHelper::runPrivoxy(const MobileHotspotConfiguration &configuration, P
 	return ret ? 0 : -1;
 }
 
-int PrivoxyHelper::stopPrivoxy(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf, QProcess *process){
+int PrivoxyHelper::stopPrivoxy(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf, QProcess *process){
 	/* 0=ok, -1=fail */
 	qDebug("Terminating Privoxy");
 	process->terminate();
 	return process->waitForFinished(5000) ? 0 : 1;
 }
 
-int PrivoxyHelper::setIptables(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf){
+int PrivoxyHelper::setIptables(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf){
 	/* 0=ok, -1=fail */
 	qDebug("Setting iptables for Privoxy");
-	QStringList commands; // $IPTABLES -t nat -A PREROUTING -i $LANIF -s $LANNET -d ! $LANNET -p tcp --dport $PORT -j REDIRECT --to-port 8118
+	QStringList commands; // $IPTABLES -t nat -A PREROUTING -i $LANIF -d ! $LANNET -p tcp --dport $PORT -j REDIRECT --to-port 8118
 	QString baseCmd("/usr/sbin/iptables -t nat -A PREROUTING");
-	baseCmd += QString(" -i ") + configuration.lanInterface;
-	baseCmd += (QString(" -s ") + configuration.lanNetwork) + "0/24";
-	baseCmd += (QString(" -d ! ") + configuration.lanNetwork) + "0/24";
+	baseCmd += QString(" -i ") + configuration->lanInterface;
+	baseCmd += (QString(" -d ! ") + configuration->lanNetwork) + "0/24";
 	baseCmd += " -p tcp --dport";
 
 	QStringList ports;
